<?php

namespace Drupal\bl\Form;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a settings for listing pages.
 */
class Settings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'bl_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'bl.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('bl.settings');

    try {
      $listingUrlConf = Json::decode($config->get('settings'));
    }
    catch (\Exception $e) {
      $listingUrlConf = [];
    }

    $types = \Drupal::entityTypeManager()
      ->getStorage('node_type')
      ->loadMultiple();
    $langs = \Drupal::languageManager()->getLanguages();

    foreach ($types as $bundle => $typeObj) {
      $form[$bundle] = [
        '#type' => 'details',
        '#title' => $typeObj->get('name') . ' (' . $bundle . ')',
      ];

      $hasSettings = FALSE;
      foreach ($langs as $lang) {
        $key = $bundle . '_' . $lang->getId();
        $value = '';
        if (!empty($listingUrlConf[$key])) {
          $hasSettings = TRUE;
          $value = trim($listingUrlConf[$key]);
        }
        $form[$bundle][$key] = [
          '#type' => 'textfield',
          '#prefix' => $lang->getName() . ', ' . $lang->getId() . ':',
          '#default_value' => $value,
        ];
      }

      $form[$bundle]['#open'] = $hasSettings;
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    unset($values['form_build_id'], $values['submit'], $values['form_token'], $values['form_id'], $values['op']);

    $this->config('bl.settings')
      ->set('settings', Json::encode($values))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
