<?php

namespace Drupal\bl\Services;

use Drupal\Component\DependencyInjection\ContainerInterface;
use Drupal\Component\Serialization\Json;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Language\LanguageManagerInterface;

/**
 * Class BackLinks.
 *
 * Provides backlinks for Listing pages configured on
 * listingpage_backlink.settings.
 */
class BackLinks {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface|mixed|null
   */
  protected $languageManager;

  /**
   * Constructs a new CustomService object.
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('language_manager'),
    );
  }

  public function __construct(
    ConfigFactoryInterface $config_factory,
    LanguageManagerInterface $language_manager,
  ) {
    $this->configFactory = $config_factory;
    $this->languageManager = $language_manager;
  }

  /**
   * Retrieve Backlink.
   *
   * @param string $node_bundle
   *   The node bundle.
   * @param string $lang_id
   *   The lang code.
   *
   * @return backlink
   *   Backlink string.
   */
  public function getBackLink($node_bundle, $lang_id = '') {
    $result = '/';
    $config = $this->configFactory->get('bl.settings');

    // Get lang ids.
    if (empty($lang_id) || $lang_id == 'default') {
      $lang_id = $this->languageManager->getCurrentLanguage()->getId();
    }
    $default_lang_id = $this->languageManager->getDefaultLanguage()->getId();

    // Read configs.
    try {
      $listingUrlConf = Json::decode($config->get('settings'));
      $key = $node_bundle . '_' . $lang_id;
      $defaultKey = $node_bundle . '_' . $default_lang_id;

      if (!empty($listingUrlConf[$key])) {
        $result = $listingUrlConf[$key];
      } else if (!empty($listingUrlConf[$defaultKey])) {
        $result = $listingUrlConf[$defaultKey];
      }
    }
    catch (\Exception $e) {
      ;
    }

    // Try alias for system pathes.
    if ($result[0] != '/') {
      $result = \Drupal::service('path_alias.manager')->getAliasByPath('/' . $result, $lang_id);
    }

    return $result;
  }

}
